Skip to main content Crate async_local Copy item path Source Context A wrapper type used for creating pointers to thread-locals LocalRef A thread-safe pointer to a thread-local Context constrained by a “generative ” lifetime brand that is invariant over the lifetime parameter and cannot be coerced into 'static AsContext A marker trait promising that AsRef <Context<T> > is implemented in a way that can’t be invalidated AsyncLocal LocalKey extension for creating thread-safe pointers to thread-local Context main Configures main to be executed by the selected Tokio runtime test Marks async function to be executed by runtime, suitable to test environment. AsContext Derive AsRef <Context<T> > and AsContext for a struct